Imports System.Text
Imports System.Xml
Imports System.IO

Imports SAS.EG.AddIns

Namespace [!output SAFE_NAMESPACE_NAME]

    Public Class [!output SAFE_ITEM_NAME]
        Implements SAS.EG.AddIns.ISASTask, SAS.EG.AddIns.ISASTaskAddIn, SAS.EG.AddIns.ISASTaskDescription

        ' keep a reference to the ISASTaskConsumer interface for the application
        Private _consumer As ISASTaskConsumer
        Private _label As String

    #Region "ISASTask implementation"

        ' perform any initialization for the add-in, and return True
        Public Function Initialize() As Boolean Implements SAS.EG.AddIns.ISASTask.Initialize
            Return True
        End Function

        Public Property Label() As String Implements SAS.EG.AddIns.ISASTask.Label
            Get
                Label = Me._label
            End Get
            Set(ByVal Value As String)
                Me._label = Value
            End Set
        End Property

        ' if the task creates output data, indicate it here
        Public ReadOnly Property OutputDataCount() As Integer Implements SAS.EG.AddIns.ISASTask.OutputDataCount
            Get
                OutputDataCount = 0
            End Get
        End Property

        Public Function OutputDataInfo(ByVal Index As Integer, ByRef Source As String, ByRef Label As String) As SAS.EG.AddIns.OutputData Implements SAS.EG.AddIns.ISASTask.OutputDataInfo
            Source = Nothing
            Label = Nothing
            OutputDataInfo = OutputData.Unknown
        End Function

        Public ReadOnly Property RunLog() As String Implements SAS.EG.AddIns.ISASTask.RunLog
            Get

            End Get
        End Property

        Public ReadOnly Property SasCode() As String Implements SAS.EG.AddIns.ISASTask.SasCode
            Get
                SasCode = "/* Your task code here! */"
            End Get
        End Property

        Public Function Show(ByVal Owner As System.Windows.Forms.IWin32Window) As SAS.EG.AddIns.ShowResult Implements SAS.EG.AddIns.ISASTask.Show
            ' show the form
            Dim form1 As New CustomTaskForm1
            If form1.ShowDialog(Owner) = Windows.Forms.DialogResult.OK Then
                Return ShowResult.RunNow
            Else : Return ShowResult.Canceled
            End If
        End Function

        Public Sub Terminate() Implements SAS.EG.AddIns.ISASTask.Terminate
            ' cleanup
        End Sub

        ' Save and retrieve the state of this task in XML format
        Public Property XmlState() As String Implements SAS.EG.AddIns.ISASTask.XmlState
            Get
                Dim sw As StringWriter = New StringWriter
                Dim writer As XmlTextWriter = New XmlTextWriter(sw)
                writer.WriteStartElement("[!output SAFE_ITEM_NAME]")
                writer.WriteEndElement()
                writer.Close()

                XmlState = sw.ToString()

            End Get
            Set(ByVal Value As String)
                If XmlState <> Nothing And XmlState.Length > 0 Then
                    Try
                        Dim sr As StringReader = New StringReader(XmlState)
                        Dim reader As XmlTextReader = New XmlTextReader(sr)
                        reader.ReadStartElement("[!output SAFE_ITEM_NAME]")
                        reader.ReadEndElement()
                        reader.Close()
                    Catch
                    End Try

                End If
            End Set
        End Property

    #End Region

    #Region "ISASTaskAddIn implementation"

        Public ReadOnly Property AddInDescription() As String Implements SAS.EG.AddIns.ISASTaskAddIn.AddInDescription
            Get
                AddInDescription = "PLACEHOLDER: Description here"
            End Get
        End Property

        Public ReadOnly Property AddInName() As String Implements SAS.EG.AddIns.ISASTaskAddIn.AddInName
            Get
                AddInName = "PLACEHOLDER: Add-In Name here"
            End Get
        End Property

        Public Function Connect(ByVal Consumer As SAS.EG.AddIns.ISASTaskConsumer) As Boolean Implements SAS.EG.AddIns.ISASTaskAddIn.Connect
            ' Save reference to the consumer application for use later
            Me._consumer = Consumer
            Connect = True
        End Function

        Public Sub Disconnect() Implements SAS.EG.AddIns.ISASTaskAddIn.Disconnect
            ' Free our reference to the consumer application
            Me._consumer = Nothing
        End Sub

        Public WriteOnly Property Language() As String Implements SAS.EG.AddIns.ISASTaskAddIn.Language
            Set(ByVal Value As String)
                ' handle different languages if necessary
            End Set
        End Property

        Public Function Languages(ByRef Items() As String) As Integer Implements SAS.EG.AddIns.ISASTaskAddIn.Languages
            ' supporting only english in this task
            Items = New String() {"en-US"}
            Languages = 1
        End Function

        Public ReadOnly Property VisibleInManager() As Boolean Implements SAS.EG.AddIns.ISASTaskAddIn.VisibleInManager
            Get
                VisibleInManager = True
            End Get
        End Property

    #End Region

    #Region "ISASTaskDescription implementation"

        Public ReadOnly Property Clsid() As String Implements SAS.EG.AddIns.ISASTaskDescription.Clsid
            Get
                ' Return GUID value generated by template
                ClsId = "[!output GUID_TASK]"
            End Get
        End Property

        Public ReadOnly Property FriendlyName() As String Implements SAS.EG.AddIns.ISASTaskDescription.FriendlyName
            Get
                FriendlyName = "PLACEHOLDER: Friendly name here"
            End Get
        End Property

        Public ReadOnly Property GeneratesListOutput() As Boolean Implements SAS.EG.AddIns.ISASTaskDescription.GeneratesListOutput
            Get
                GeneratesListOutput = True
            End Get
        End Property

        Public ReadOnly Property GeneratesSasCode() As Boolean Implements SAS.EG.AddIns.ISASTaskDescription.GeneratesSasCode
            Get
                GeneratesSasCode = True
            End Get
        End Property

        Public ReadOnly Property IconAssembly() As String Implements SAS.EG.AddIns.ISASTaskDescription.IconAssembly
            Get
                ' return this assembly as the icon assembly
                IconAssembly = System.Reflection.Assembly.GetExecutingAssembly.Location
            End Get
        End Property

        Public ReadOnly Property IconName() As String Implements SAS.EG.AddIns.ISASTaskDescription.IconName
            Get
                IconName = "[!output SAFE_NAMESPACE_NAME].CustomTask.ico"
            End Get
        End Property

        Public ReadOnly Property MajorVersion() As Integer Implements SAS.EG.AddIns.ISASTaskDescription.MajorVersion
            Get
                MajorVersion = 1
            End Get
        End Property

        Public ReadOnly Property MinorVersion() As Integer Implements SAS.EG.AddIns.ISASTaskDescription.MinorVersion
            Get
                MinorVersion = 1
            End Get
        End Property

        Public ReadOnly Property NumericColsRequired() As Integer Implements SAS.EG.AddIns.ISASTaskDescription.NumericColsRequired
            Get
                NumericColsRequired = 0
            End Get
        End Property

        Public ReadOnly Property ProcsUsed() As String Implements SAS.EG.AddIns.ISASTaskDescription.ProcsUsed
            Get
                ProcsUsed = ""
            End Get
        End Property

        Public ReadOnly Property ProductsOptional() As String Implements SAS.EG.AddIns.ISASTaskDescription.ProductsOptional
            Get
                ProductsOptional = ""
            End Get
        End Property

        Public ReadOnly Property ProductsRequired() As String Implements SAS.EG.AddIns.ISASTaskDescription.ProductsRequired
            Get
                ProductsRequired = "BASE"
            End Get
        End Property

        Public ReadOnly Property RequiresData() As Boolean Implements SAS.EG.AddIns.ISASTaskDescription.RequiresData
            Get
                RequiresData = False
            End Get
        End Property

        Public ReadOnly Property StandardCategory() As Boolean Implements SAS.EG.AddIns.ISASTaskDescription.StandardCategory
            Get
                StandardCategory = False
            End Get
        End Property

        Public ReadOnly Property TaskCategory() As String Implements SAS.EG.AddIns.ISASTaskDescription.TaskCategory
            Get
                TaskCategory = "SAS Custom Task"
            End Get
        End Property

        Public ReadOnly Property TaskDescription() As String Implements SAS.EG.AddIns.ISASTaskDescription.TaskDescription
            Get
                TaskDescription = "PLACEHOLDER: Task description here"
            End Get
        End Property

        Public ReadOnly Property TaskName() As String Implements SAS.EG.AddIns.ISASTaskDescription.TaskName
            Get
                TaskName = "PLACEHOLDER: Task name here"
            End Get
        End Property

        Public ReadOnly Property TaskType() As SAS.EG.AddIns.ShowType Implements SAS.EG.AddIns.ISASTaskDescription.TaskType
            Get
                TaskType = SAS.EG.AddIns.ShowType.Wizard
            End Get
        End Property

        Public ReadOnly Property Validation() As String Implements SAS.EG.AddIns.ISASTaskDescription.Validation
            Get
                Validation = ""
            End Get
        End Property

        Public ReadOnly Property WhatIsDescription() As String Implements SAS.EG.AddIns.ISASTaskDescription.WhatIsDescription
            Get
                WhatIsDescription = "PLACEHOLDER: Longer description here"
            End Get
        End Property

    #End Region

    End Class

End Namespace
